use std::path::{Path, PathBuf};

use crate::action::ActionErrorKind;

/// Finds the top-level path in the tarball, e.g. lix-2.90.0-rc1-x86_64-linux
pub fn find_toplevel_path(unpacked_path: &Path) -> Result<PathBuf, ActionErrorKind> {
    let found_nix_paths = glob::glob(&format!("{}/[nl]ix-*", unpacked_path.display()))
        .map_err(ActionErrorKind::from)?
        .collect::<Result<Vec<_>, _>>()
        .map_err(ActionErrorKind::from)?;
    if found_nix_paths.len() != 1 {
        return Err(ActionErrorKind::MalformedBinaryTarball);
    }
    let found_nix_path = found_nix_paths.into_iter().next().unwrap();

    Ok(found_nix_path)
}
